@@ -2,7 +2,7 @@
  * gpe-conf
  *
  * Copyright (C) 2002  Pierre TARDY <tardyp@free.fr>
- *               2003 - 2005  Florian Boor <florian.boor@kernelconcepts.de>
+ *               2003 - 2006  Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,7 +51,7 @@ file_set_line (const gchar *file, const gchar *pattern, const gchar *newline)
 {
 	gchar *content = NULL;
 	gchar **lines = NULL;
-	gint length;
+	guint length;
 	gchar *delim;
 	FILE *fnew;
 	gint i = 0;
@@ -125,7 +125,7 @@ change_cfg_value (const gchar *file, const gchar *var, const gchar *val,
 {
 	gchar *content, *tmpval;
 	gchar **lines = NULL;
-	gint length;
+	guint length;
 	gchar *delim;
 	FILE *fnew;
 	gint i = 0;
@@ -311,7 +311,7 @@ freedata (GtkWidget * ignored, gpointer user_data)
 }
 
 void
-ask_user_a_file (char *path, char *prompt,
+ask_user_a_file (const char *path, char *prompt,
 		 void (*File_Selected) (char *filename, gpointer data),
 		 void (*Cancel) (gpointer data), gpointer data)
 {
