@@ -2,7 +2,7 @@
  * gpe-conf
  *
  * Copyright (C) 2002  Pierre TARDY <tardyp@free.fr>
- *               2003 - 2005  Florian Boor <florian.boor@kernelconcepts.de>
+ *               2003 - 2005, 2007  Florian Boor <florian.boor@kernelconcepts.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -57,7 +57,13 @@ int check_user_access (const char *cmd);
 void
 update_screen_brightness (int br)
 {
-	set_brightness (br);
+	backlight_set_brightness (br);
+}
+
+void
+update_screen_power (int power)
+{
+	backlight_set_power (power ? TRUE : FALSE);
 }
 
 #ifndef DISABLE_XRANDR
@@ -75,6 +81,24 @@ update_dns_server (const gchar * server)
 	change_cfg_value ("/etc/resolv.conf", "nameserver", server, ' ');
 }
 
+void
+update_system_hostname (const gchar * system_hostname)
+{
+	FILE *fnew;
+	static gchar *file = "/etc/hostname";
+
+	fnew = fopen (file, "w");
+	if (!fnew)
+	{
+		fprintf (stderr, "Could not write to file: %s\n", file);
+		return;
+	}
+
+	fprintf (fnew, system_hostname);
+
+	fclose (fnew);
+}
+
 void
 update_time_from_net (const gchar * server)
 {
@@ -179,6 +203,8 @@ check_user_access (const char *cmd)
 		return TRUE;
 	if (!strcmp (cmd, "SCRB"))
 		return TRUE;
+	if (!strcmp (cmd, "SCRP"))
+		return TRUE;
 	if (!strcmp (cmd, "SCRL"))
 		return TRUE;
 
@@ -281,7 +307,7 @@ suidloop (int write, int read)
 				else if (strcmp (cmd, "STZO") == 0)  // changes the timezone setting 
 				{
 					fscanf (in, "%100s", arg2);
-					set_timezone ("/etc/profile",arg2);
+					set_timezone (arg2);
 				}
 				else if (strcmp (cmd, "ULBS") == 0)  // turn login bg on/off
 				{
@@ -308,11 +334,21 @@ suidloop (int write, int read)
 					fscanf (in, "%100s", arg2);
 					update_dns_server (arg2);
 				}
-				else if (strcmp (cmd, "SCRB") == 0)  // change frontlight brightness
+				else if (strcmp (cmd, "HOST") == 0)  // change to another system-hostname
+				{
+					fscanf (in, "%100s", arg2);
+					update_system_hostname (arg2);
+				}
+				else if (strcmp (cmd, "SCRB") == 0)  // change light brightness
 				{
 					fscanf (in, "%d", &numarg);
 					update_screen_brightness (numarg);
 				}
+				else if (strcmp (cmd, "SCRP") == 0)  // change light power
+				{
+					fscanf (in, "%d", &numarg);
+					update_screen_power (numarg);
+				}
 #ifndef DISABLE_XRANDR
 				else if (strcmp (cmd, "SCRR") == 0)  // rotate screen
 				{
